<?php

/*
  this page is used as doxygen output mainpage,
  content is pasted in from README.
*/

/**
\mainpage


TikiWiki CMS/Groupware is Free and Open Source Software (FOSS). It is a community-driven project which exists and improves thanks to the participation of people just like YOU.


IMPORTANT LINKS
---------------
* General information & overview
  http://info.tikiwiki.org

* Official TikiWiki documentation website
  http://doc.tikiwiki.org

* Forums & community
  http://tikiwiki.org/tiki-forums.php

* Developers
  http://dev.tikiwiki.org

* Themes & styling
  http://themes.tikiwiki.org

* Security
  http://security.tikiwiki.org

* IRC chat channel: #tikiwiki on irc.freenode.net
  http://irc.tikiwiki.org/



INSTALLATION
------------
Please see the INSTALL file in this folder for basic installation instructions.
For more details, please see:
http://doc.tikiwiki.org/Installation



COPYRIGHT
---------
Copyright (c) 2002-2008, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.All
Rights Reserved. See copyright.txt for details and a complete list of authors.
Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.


... Have fun!
*/

// I call index.php because tiki may not be setup when people attempt to call this.
header ("location: index.php");
die;

